var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __reExport = (target, mod, secondTarget) => (__copyProps(target, mod, "default"), secondTarget && __copyProps(secondTarget, mod, "default"));

// node_modules/@girs/gnome-shell/dist/extensions/prefs.js
var prefs_exports = {};
__reExport(prefs_exports, prefs_star);
import * as prefs_star from "resource:///org/gnome/Shell/Extensions/js/extensions/prefs.js";

// src/prefs.ts
import Gtk4 from "gi://Gtk";
import Adw from "gi://Adw";
import Gio from "gi://Gio";
import Gdk from "gi://Gdk";
import GLib from "gi://GLib";
var GnomeRectanglePreferences = class extends prefs_exports.ExtensionPreferences {
  _settings;
  _radios = [];
  _addRadio(radioName, radioUrl) {
    this._radios.push(`${radioName} - ${radioUrl}`);
    this._settings.set_strv("radios", this._radios);
  }
  _handleErrorRadioRow(radioRow, errorMessage) {
    const TIMEOUT_SECONDS = 3;
    const currentRadioRowTitle = radioRow.get_title();
    radioRow.add_css_class("error");
    radioRow.set_title(errorMessage);
    GLib.timeout_add_seconds(GLib.PRIORITY_HIGH, TIMEOUT_SECONDS, () => {
      radioRow.set_title(currentRadioRowTitle);
      radioRow.remove_css_class("error");
      return GLib.SOURCE_REMOVE;
    });
  }
  _populateRadios(radiosGroup) {
    for (let i = 0; i < this._radios.length; i++) {
      const [radioName, radioUrl] = this._radios[i].split(" - ");
      const radiosExpander = new Adw.ExpanderRow({ title: (0, prefs_exports.gettext)(radioName), cursor: new Gdk.Cursor({ name: "pointer" }) });
      const nameRadioRow = new Adw.EntryRow({
        title: (0, prefs_exports.gettext)("Radio Name"),
        text: (0, prefs_exports.gettext)(radioName),
        showApplyButton: true
      });
      const urlRadioRow = new Adw.EntryRow({ title: (0, prefs_exports.gettext)("Radio Name"), text: (0, prefs_exports.gettext)(radioUrl), showApplyButton: true });
      const removeButton = new Gtk4.Button({
        label: `Remove ${radioName}`,
        iconName: "user-trash-symbolic",
        cursor: new Gdk.Cursor({ name: "pointer" }),
        halign: Gtk4.Align.CENTER,
        valign: Gtk4.Align.CENTER
      });
      removeButton.connect("clicked", () => {
        const messsageDialog = new Gtk4.MessageDialog({
          text: (0, prefs_exports.gettext)(`Are you sure you want to delete ${radioName} ?`),
          destroyWithParent: true,
          modal: true,
          visible: true,
          buttons: Gtk4.ButtonsType.OK_CANCEL
        });
        messsageDialog.connect("response", (_2, response) => {
          if (response === Gtk4.ResponseType.OK) {
            this._removeRadio(i);
            this._reloadRadios(radiosGroup);
          }
          messsageDialog.destroy();
        });
      });
      nameRadioRow.connect("apply", (w) => {
        if (w.text.length < 2) {
          this._handleErrorRadioRow(w, "Name must be at least 2 characters");
          w.set_text(radioName);
          return;
        }
        const index = this._radios.findIndex((entry) => entry.startsWith(radioName));
        this._updateRadio(index, "radioName", w.text);
        radiosExpander.set_title(w.text);
      });
      urlRadioRow.connect("apply", (w) => {
        try {
          GLib.uri_is_valid(w.text, GLib.UriFlags.NONE);
          const index = this._radios.findIndex((entry) => entry.startsWith(radioName));
          this._updateRadio(index, "radioUrl", w.text);
        } catch (e) {
          this._handleErrorRadioRow(w, "Invalid URL");
          w.set_text(radioUrl);
        }
      });
      radiosExpander.add_row(nameRadioRow);
      radiosExpander.add_row(urlRadioRow);
      radiosExpander.add_row(removeButton);
      radiosGroup.add(radiosExpander);
    }
  }
  _reloadRadios(radiosGroup) {
    let index = 0;
    const l = this._radios.length;
    while (l >= index) {
      const child = radiosGroup.get_first_child().get_first_child().get_next_sibling().get_first_child().get_first_child();
      if (child === null)
        break;
      radiosGroup.remove(child);
      index++;
    }
    this._populateRadios(radiosGroup);
  }
  _removeRadio(index) {
    this._radios.splice(index, 1);
    this._settings.set_strv("radios", this._radios);
  }
  _updateRadio(index, field, content) {
    if (index !== -1) {
      const radio = this._radios[index];
      const [radioName, radioUrl] = radio.split(" - ");
      if (field === "radioUrl") {
        this._radios[index] = `${radioName} - ${content}`;
      }
      if (field === "radioName") {
        this._radios[index] = `${content} - ${radioUrl}`;
      }
      this._settings.set_strv("radios", this._radios);
      return true;
    }
    return false;
  }
  fillPreferencesWindow(window) {
    this._settings = this.getSettings();
    this._radios = this._settings.get_strv("radios");
    const page = new Adw.PreferencesPage({
      title: (0, prefs_exports.gettext)("General"),
      icon_name: "dialog-information-symbolic"
    });
    const volumeGroup = new Adw.PreferencesGroup({
      title: (0, prefs_exports.gettext)("Player Settings"),
      description: (0, prefs_exports.gettext)("Configure the player settings")
    });
    page.add(volumeGroup);
    const volumeLevel = new Adw.SpinRow({
      title: (0, prefs_exports.gettext)("Volume"),
      subtitle: (0, prefs_exports.gettext)("Volume to set when playing lofi"),
      cursor: new Gdk.Cursor({ name: "pointer" }),
      adjustment: new Gtk4.Adjustment({
        lower: 0,
        upper: 100,
        step_increment: 1
      })
    });
    volumeGroup.add(volumeLevel);
    const radiosGroup = new Adw.PreferencesGroup({
      title: (0, prefs_exports.gettext)("Radios Settings"),
      description: (0, prefs_exports.gettext)("Configure the radio list")
    });
    this._populateRadios(radiosGroup);
    const addRadioGroup = new Adw.PreferencesGroup({
      title: (0, prefs_exports.gettext)("Add Radio to the list")
    });
    const nameRadioRow = new Adw.EntryRow({ title: (0, prefs_exports.gettext)("Radio Name") });
    const urlRadioRow = new Adw.EntryRow({ title: (0, prefs_exports.gettext)("Radio URL") });
    const addButton = new Gtk4.Button({
      label: (0, prefs_exports.gettext)("Add Radio"),
      iconName: "list-add-symbolic",
      cursor: new Gdk.Cursor({ name: "pointer" }),
      halign: Gtk4.Align.CENTER,
      valign: Gtk4.Align.CENTER,
      marginTop: 10
    });
    addButton.connect("clicked", () => {
      try {
        GLib.uri_is_valid(urlRadioRow.text, GLib.UriFlags.NONE);
        if (nameRadioRow.text.length < 2) {
          this._handleErrorRadioRow(nameRadioRow, "Name must be at least 2 characters");
          return;
        }
        this._addRadio(nameRadioRow.text, urlRadioRow.text);
        nameRadioRow.set_text("");
        urlRadioRow.set_text("");
        this._reloadRadios(radiosGroup);
      } catch (e) {
        this._handleErrorRadioRow(urlRadioRow, "Invalid URL");
        if (nameRadioRow.text.length < 2) {
          this._handleErrorRadioRow(nameRadioRow, "Name must be at least 2 characters");
        }
      }
    });
    addRadioGroup.add(nameRadioRow);
    addRadioGroup.add(urlRadioRow);
    addRadioGroup.add(addButton);
    page.add(radiosGroup);
    page.add(addRadioGroup);
    window.connect("close-request", () => {
      this._settings = null;
      this._radios = null;
    });
    window.add(page);
    this._settings.bind("volume", volumeLevel, "value", Gio.SettingsBindFlags.DEFAULT);
  }
};
export {
  GnomeRectanglePreferences as default
};
